@@ -9,10 +9,8 @@ import cz.startnet.utils.pgdiff.schema.PgColumn;
 import cz.startnet.utils.pgdiff.schema.PgColumnUtils;
 import cz.startnet.utils.pgdiff.schema.PgSchema;
 import cz.startnet.utils.pgdiff.schema.PgTable;
-
 import java.io.PrintWriter;
 import java.text.MessageFormat;
-
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -25,18 +23,12 @@ import java.util.Map;
  */
 public class PgDiffTables {
 
-    /**
-     * Creates a new instance of PgDiffTables.
-     */
-    private PgDiffTables() {
-    }
-
     /**
      * Outputs statements for creation of clusters.
      *
-     * @param writer writer the output should be written to
-     * @param oldSchema original schema
-     * @param newSchema new schema
+     * @param writer           writer the output should be written to
+     * @param oldSchema        original schema
+     * @param newSchema        new schema
      * @param searchPathHelper search path helper
      */
     public static void dropClusters(final PrintWriter writer,
@@ -75,9 +67,9 @@ public class PgDiffTables {
     /**
      * Outputs statements for dropping of clusters.
      *
-     * @param writer writer the output should be written to
-     * @param oldSchema original schema
-     * @param newSchema new schema
+     * @param writer           writer the output should be written to
+     * @param oldSchema        original schema
+     * @param newSchema        new schema
      * @param searchPathHelper search path helper
      */
     public static void createClusters(final PrintWriter writer,
@@ -119,10 +111,10 @@ public class PgDiffTables {
     /**
      * Outputs statements for altering tables.
      *
-     * @param writer writer the output should be written to
-     * @param arguments object containing arguments settings
-     * @param oldSchema original schema
-     * @param newSchema new schema
+     * @param writer           writer the output should be written to
+     * @param arguments        object containing arguments settings
+     * @param oldSchema        original schema
+     * @param newSchema        new schema
      * @param searchPathHelper search path helper
      */
     public static void alterTables(final PrintWriter writer,
@@ -149,9 +141,9 @@ public class PgDiffTables {
     /**
      * Generate the needed alter table xxx set statistics when needed.
      *
-     * @param writer writer the output should be written to
-     * @param oldTable original table
-     * @param newTable new table
+     * @param writer           writer the output should be written to
+     * @param oldTable         original table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void addAlterStatistics(final PrintWriter writer,
@@ -197,9 +189,9 @@ public class PgDiffTables {
     /**
      * Generate the needed alter table xxx set storage when needed.
      *
-     * @param writer writer the output should be written to
-     * @param oldTable original table
-     * @param newTable new table
+     * @param writer           writer the output should be written to
+     * @param oldTable         original table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void addAlterStorage(final PrintWriter writer,
@@ -244,12 +236,12 @@ public class PgDiffTables {
     /**
      * Adds statements for creation of new columns to the list of statements.
      *
-     * @param statements list of statements
-     * @param arguments object containing arguments settings
-     * @param oldTable original table
-     * @param newTable new table
+     * @param statements          list of statements
+     * @param arguments           object containing arguments settings
+     * @param oldTable            original table
+     * @param newTable            new table
      * @param dropDefaultsColumns list for storing columns for which default
-     *        value should be dropped
+     *                            value should be dropped
      */
     private static void addCreateTableColumns(final List<String> statements,
             final PgDiffArguments arguments, final PgTable oldTable,
@@ -259,7 +251,9 @@ public class PgDiffTables {
                 statements.add("\tADD COLUMN "
                         + column.getFullDefinition(arguments.isAddDefaults()));
 
-                if (arguments.isAddDefaults() && !column.getNullValue()) {
+                if (arguments.isAddDefaults() && !column.getNullValue()
+                        && (column.getDefaultValue() == null
+                        || column.getDefaultValue().isEmpty())) {
                     dropDefaultsColumns.add(column);
                 }
             }
@@ -270,8 +264,8 @@ public class PgDiffTables {
      * Adds statements for removal of columns to the list of statements.
      *
      * @param statements list of statements
-     * @param oldTable original table
-     * @param newTable new table
+     * @param oldTable   original table
+     * @param newTable   new table
      */
     private static void addDropTableColumns(final List<String> statements,
             final PgTable oldTable, final PgTable newTable) {
@@ -286,12 +280,12 @@ public class PgDiffTables {
     /**
      * Adds statements for modification of columns to the list of statements.
      *
-     * @param statements list of statements
-     * @param arguments object containing arguments settings
-     * @param oldTable original table
-     * @param newTable new table
+     * @param statements          list of statements
+     * @param arguments           object containing arguments settings
+     * @param oldTable            original table
+     * @param newTable            new table
      * @param dropDefaultsColumns list for storing columns for which default
-     *        value should be dropped
+     *                            value should be dropped
      */
     private static void addModifyTableColumns(final List<String> statements,
             final PgDiffArguments arguments, final PgTable oldTable,
@@ -354,12 +348,12 @@ public class PgDiffTables {
     }
 
     /**
-     * Checks whether there is a discrepancy in INHERITS for original
-     * and new table.
+     * Checks whether there is a discrepancy in INHERITS for original and new
+     * table.
      *
-     * @param writer writer the output should be written to
-     * @param oldTable original table
-     * @param newTable new table
+     * @param writer           writer the output should be written to
+     * @param oldTable         original table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void checkInherits(final PrintWriter writer,
@@ -389,13 +383,13 @@ public class PgDiffTables {
     }
 
     /**
-     * Checks whether OIDS are dropped from the new table. There is no
-     * way to add OIDS to existing table so we do not create SQL statement for
-     * addition of OIDS but we issue warning.
+     * Checks whether OIDS are dropped from the new table. There is no way to
+     * add OIDS to existing table so we do not create SQL statement for addition
+     * of OIDS but we issue warning.
      *
-     * @param writer writer the output should be written to
-     * @param oldTable original table
-     * @param newTable new table
+     * @param writer           writer the output should be written to
+     * @param oldTable         original table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void checkWithOIDS(final PrintWriter writer,
@@ -426,9 +420,9 @@ public class PgDiffTables {
     /**
      * Checks tablespace modification.
      *
-     * @param writer writer
-     * @param oldTable old table
-     * @param newTable new table
+     * @param writer           writer
+     * @param oldTable         old table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void checkTablespace(final PrintWriter writer,
@@ -450,9 +444,9 @@ public class PgDiffTables {
     /**
      * Outputs statements for creation of new tables.
      *
-     * @param writer writer the output should be written to
-     * @param oldSchema original schema
-     * @param newSchema new schema
+     * @param writer           writer the output should be written to
+     * @param oldSchema        original schema
+     * @param newSchema        new schema
      * @param searchPathHelper search path helper
      */
     public static void createTables(final PrintWriter writer,
@@ -471,9 +465,9 @@ public class PgDiffTables {
     /**
      * Outputs statements for dropping tables.
      *
-     * @param writer writer the output should be written to
-     * @param oldSchema original schema
-     * @param newSchema new schema
+     * @param writer           writer the output should be written to
+     * @param oldSchema        original schema
+     * @param newSchema        new schema
      * @param searchPathHelper search path helper
      */
     public static void dropTables(final PrintWriter writer,
@@ -493,13 +487,13 @@ public class PgDiffTables {
     }
 
     /**
-     * Outputs statements for addition, removal and modifications of
-     * table columns.
+     * Outputs statements for addition, removal and modifications of table
+     * columns.
      *
-     * @param writer writer the output should be written to
-     * @param arguments object containing arguments settings
-     * @param oldTable original table
-     * @param newTable new table
+     * @param writer           writer the output should be written to
+     * @param arguments        object containing arguments settings
+     * @param oldTable         original table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void updateTableColumns(final PrintWriter writer,
@@ -547,9 +541,9 @@ public class PgDiffTables {
      * Outputs statements for tables and columns for which comments have
      * changed.
      *
-     * @param writer writer
-     * @param oldTable old table
-     * @param newTable new table
+     * @param writer           writer
+     * @param oldTable         old table
+     * @param newTable         new table
      * @param searchPathHelper search path helper
      */
     private static void alterComments(final PrintWriter writer,
@@ -576,18 +570,14 @@ public class PgDiffTables {
             writer.println(" IS NULL;");
         }
 
-        for (final PgColumn oldColumn : oldTable.getColumns()) {
-            final PgColumn newColumn = newTable.getColumn(oldColumn.getName());
+        for (final PgColumn newColumn : newTable.getColumns()) {
+            final PgColumn oldColumn = oldTable.getColumn(newColumn.getName());
+            final String oldComment =
+                    oldColumn == null ? null : oldColumn.getComment();
+            final String newComment = newColumn.getComment();
 
-            if (newColumn == null) {
-                continue;
-            }
-
-            if (oldColumn.getComment() == null
-                    && newColumn.getComment() != null
-                    || oldColumn.getComment() != null
-                    && newColumn.getComment() != null
-                    && !oldColumn.getComment().equals(newColumn.getComment())) {
+            if (newComment != null && (oldComment == null ? newComment != null
+                    : !oldComment.equals(newComment))) {
                 searchPathHelper.outputSearchPath(writer);
                 writer.println();
                 writer.print("COMMENT ON COLUMN ");
@@ -597,8 +587,7 @@ public class PgDiffTables {
                 writer.print(" IS ");
                 writer.print(newColumn.getComment());
                 writer.println(';');
-            } else if (oldColumn.getComment() != null
-                    && newColumn.getComment() == null) {
+            } else if (oldComment != null && newComment == null) {
                 searchPathHelper.outputSearchPath(writer);
                 writer.println();
                 writer.print("COMMENT ON COLUMN ");
@@ -609,4 +598,10 @@ public class PgDiffTables {
             }
         }
     }
+
+    /**
+     * Creates a new instance of PgDiffTables.
+     */
+    private PgDiffTables() {
+    }
 }
