@@ -1,3 +1,8 @@
+/**
+ * Copyright 2006 StartNet s.r.o.
+ *
+ * Distributed under MIT license
+ */
 package cz.startnet.utils.pgdiff.schema;
 
 import cz.startnet.utils.pgdiff.PgDiffUtils;
@@ -25,6 +30,10 @@ public class PgIndex {
      * Whether the index is unique.
      */
     private boolean unique;
+    /**
+     * Comment.
+     */
+    private String comment;
 
     /**
      * Creates a new PgIndex object.
@@ -32,19 +41,34 @@ public class PgIndex {
      * @param name {@link #name}
      */
     public PgIndex(final String name) {
-        super();
         this.name = name;
     }
 
+    /**
+     * Getter for {@link #comment}.
+     *
+     * @return {@link #comment}
+     */
+    public String getComment() {
+        return comment;
+    }
+
+    /**
+     * Setter for {@link #comment}.
+     *
+     * @param comment {@link #comment}
+     */
+    public void setComment(final String comment) {
+        this.comment = comment;
+    }
+
     /**
      * Creates and returns SQL for creation of the index.
      *
-     * @param quoteNames whether names should be quoted
-     *
      * @return created SQL
      */
-    public String getCreationSQL(final boolean quoteNames) {
-        final StringBuilder sbSQL = new StringBuilder();
+    public String getCreationSQL() {
+        final StringBuilder sbSQL = new StringBuilder(100);
         sbSQL.append("CREATE ");
 
         if (isUnique()) {
@@ -52,13 +76,21 @@ public class PgIndex {
         }
 
         sbSQL.append("INDEX ");
-        sbSQL.append(PgDiffUtils.getQuotedName(getName(), quoteNames));
+        sbSQL.append(PgDiffUtils.getQuotedName(getName()));
         sbSQL.append(" ON ");
-        sbSQL.append(PgDiffUtils.getQuotedName(getTableName(), quoteNames));
+        sbSQL.append(PgDiffUtils.getQuotedName(getTableName()));
         sbSQL.append(' ');
         sbSQL.append(getDefinition());
         sbSQL.append(';');
 
+        if (comment != null && !comment.isEmpty()) {
+            sbSQL.append("\n\nCOMMENT ON INDEX ");
+            sbSQL.append(PgDiffUtils.getQuotedName(name));
+            sbSQL.append(" IS ");
+            sbSQL.append(comment);
+            sbSQL.append(';');
+        }
+
         return sbSQL.toString();
     }
 
@@ -81,15 +113,12 @@ public class PgIndex {
     }
 
     /**
-     * Creates and returns SQL command for dropping the index.
+     * Creates and returns SQL statement for dropping the index.
      *
-     * @param quoteNames whether names should be quoted
-     *
-     * @return created SQL command
+     * @return created SQL statement
      */
-    public String getDropSQL(final boolean quoteNames) {
-        return "DROP INDEX " + PgDiffUtils.getQuotedName(getName(), quoteNames)
-                + ";";
+    public String getDropSQL() {
+        return "DROP INDEX " + PgDiffUtils.getQuotedName(getName()) + ";";
     }
 
     /**
@@ -143,10 +172,10 @@ public class PgIndex {
             equals = true;
         } else if (object instanceof PgIndex) {
             final PgIndex index = (PgIndex) object;
-            equals = definition.equals(index.definition)
-                    && name.equals(index.name)
-                    && tableName.equals(index.tableName)
-                    && unique == index.unique;
+            equals = definition.equals(index.getDefinition())
+                    && name.equals(index.getName())
+                    && tableName.equals(index.getTableName())
+                    && unique == index.isUnique();
         }
 
         return equals;
