@@ -5,24 +5,20 @@
  */
 package cz.startnet.utils.pgdiff;
 
-import org.junit.Assert;
-import org.junit.Test;
-
-import org.junit.runner.RunWith;
-
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
-
 import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.PrintWriter;
-
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Locale;
+import org.junit.Assert;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
+import org.junit.runners.Parameterized.Parameters;
 
 /**
  * Tests for PgDiff class.
@@ -32,51 +28,6 @@ import java.util.Locale;
 @RunWith(value = Parameterized.class)
 public class PgDiffTest {
 
-    /**
-     * Template name for file names that should be used for the test.
-     * Testing method adds _original.sql, _new.sql and _diff.sql to the file
-     * name template.
-     */
-    private final String fileNameTemplate;
-    /**
-     * Value for the same named command line argument.
-     */
-    private final boolean addDefaults;
-    /**
-     * Value for the same named command line argument.
-     */
-    private final boolean addTransaction;
-    /**
-     * Value for the same named command line argument.
-     */
-    private final boolean ignoreFunctionWhitespace;
-    /**
-     * Value for the same named command line argument.
-     */
-    private final boolean ignoreStartWith;
-
-    /**
-     * Creates a new PgDiffTest object.
-     *
-     * @param fileNameTemplate {@link #fileNameTemplate}
-     * @param addDefaults {@link #addDefaults}
-     * @param addTransaction {@link #addTransaction}
-     * @param ignoreFunctionWhitespace {@link #ignoreFunctionWhitespace}
-     * @param ignoreStartWith {@link #ignoreStartWith}
-     */
-    public PgDiffTest(final String fileNameTemplate,
-            final boolean addDefaults, final boolean addTransaction,
-            final boolean ignoreFunctionWhitespace,
-            final boolean ignoreStartWith) {
-        super();
-        this.fileNameTemplate = fileNameTemplate;
-        this.addDefaults = addDefaults;
-        this.addTransaction = addTransaction;
-        this.ignoreFunctionWhitespace = ignoreFunctionWhitespace;
-        this.ignoreStartWith = ignoreStartWith;
-        Locale.setDefault(Locale.ENGLISH);
-    }
-
     /**
      * Provides parameters for running the tests.
      *
@@ -243,16 +194,70 @@ public class PgDiffTest {
                     // Tests view with default value
                     {"view_bug3080388", false, true, false, false},
                     // Tests function arguments beginning with in_
-                    {"function_bug3084274", false, true, false, false}
+                    {"function_bug3084274", false, true, false, false},
+                    // Tests addition of comment when new column has been added
+                    {"add_comment_new_column", false, true, false, false},
+                    // Tests handling of quoted schemas in search_path
+                    {"quoted_schema", false, true, false, false},
+                    // Tests adding new column with add defaults turned on
+                    {"add_column_add_defaults", true, true, false, false},
+                    // Tests adding new sequence that is owned by table
+                    {"add_owned_sequence", false, true, false, false},
+                    // Tests adding empty table
+                    {"add_empty_table", false, false, false, false}
                 });
     }
+    /**
+     * Template name for file names that should be used for the test. Testing
+     * method adds _original.sql, _new.sql and _diff.sql to the file name
+     * template.
+     */
+    private final String fileNameTemplate;
+    /**
+     * Value for the same named command line argument.
+     */
+    private final boolean addDefaults;
+    /**
+     * Value for the same named command line argument.
+     */
+    private final boolean addTransaction;
+    /**
+     * Value for the same named command line argument.
+     */
+    private final boolean ignoreFunctionWhitespace;
+    /**
+     * Value for the same named command line argument.
+     */
+    private final boolean ignoreStartWith;
+
+    /**
+     * Creates a new PgDiffTest object.
+     *
+     * @param fileNameTemplate         {@link #fileNameTemplate}
+     * @param addDefaults              {@link #addDefaults}
+     * @param addTransaction           {@link #addTransaction}
+     * @param ignoreFunctionWhitespace {@link #ignoreFunctionWhitespace}
+     * @param ignoreStartWith          {@link #ignoreStartWith}
+     */
+    public PgDiffTest(final String fileNameTemplate,
+            final boolean addDefaults, final boolean addTransaction,
+            final boolean ignoreFunctionWhitespace,
+            final boolean ignoreStartWith) {
+        super();
+        this.fileNameTemplate = fileNameTemplate;
+        this.addDefaults = addDefaults;
+        this.addTransaction = addTransaction;
+        this.ignoreFunctionWhitespace = ignoreFunctionWhitespace;
+        this.ignoreStartWith = ignoreStartWith;
+        Locale.setDefault(Locale.ENGLISH);
+    }
 
     /**
      * Runs single test on original schema.
      *
      * @throws FileNotFoundException Thrown if expected diff file was not found.
-     * @throws IOException Thrown if problem occurred while reading expected
-     * diff.
+     * @throws IOException           Thrown if problem occurred while reading
+     *                               expected diff.
      */
     @Test(timeout = 1000)
     public void runDiffSameOriginal() throws FileNotFoundException, IOException {
@@ -274,8 +279,8 @@ public class PgDiffTest {
      * Runs single test on new schema.
      *
      * @throws FileNotFoundException Thrown if expected diff file was not found.
-     * @throws IOException Thrown if problem occurred while reading expected
-     * diff.
+     * @throws IOException           Thrown if problem occurred while reading
+     *                               expected diff.
      */
     @Test(timeout = 1000)
     public void runDiffSameNew() throws FileNotFoundException, IOException {
@@ -297,8 +302,8 @@ public class PgDiffTest {
      * Runs single test using class member variables.
      *
      * @throws FileNotFoundException Thrown if expected diff file was not found.
-     * @throws IOException Thrown if problem occurred while reading expected
-     * diff.
+     * @throws IOException           Thrown if problem occurred while reading
+     *                               expected diff.
      */
     @Test(timeout = 1000)
     public void runDiff() throws FileNotFoundException, IOException {
