@@ -11,6 +11,9 @@ CREATE TABLE testtable2 (
 	col1 boolean NOT NULL
 );
 
+ALTER SEQUENCE testtable2_id_seq
+	OWNED BY testtable2.id;
+
 CREATE INDEX testindex ON testtable USING btree (field1);
 
 CREATE INDEX testtable2_col1 ON testtable2 USING btree (col1);
