@@ -7,4 +7,8 @@ ALTER TABLE parenttable
 	DROP COLUMN id,
 	ADD COLUMN field3 information_schema.cardinal_number;
 
-Modified INHERITS on TABLE testtable: original table uses INHERITS (parenttable) but new table uses INHERITS (parenttable2)
+ALTER TABLE testtable
+	NO INHERIT parenttable;
+
+ALTER TABLE testtable
+	INHERIT parenttable2;
